## Open IoE

Open IoE is a simple IoT platform to operate IoT devices.

There are two options available,

1.  API creation and Consumption (REST APIs)
2.  Python Library (Client)

---

### 1\. API Creation for IoT Device and Its Consumption

Users are expected to take these steps,

1.  Add device using [Link \<Add Device>](http://gnanodaya.org:8080/openioe/device.jsp)
2.  (Optional) Verify device data or API using [Link \<Verify Device>](http://gnanodaya.org:8080/openioe/console.jsp)
3.  Embed the API in your application using [Client Code/API](http://gnanodaya.org:8080/openioe/embed.jsp)

#### Visit the OpenIoE 1.0 web portal at [https://v3.openioe.in](https://v3.openioe.in)

#### API List:

<table><tbody><tr><td><strong>No</strong></td><td><strong>API</strong></td><td><strong>Description</strong></td><td><strong>Type</strong></td><td><strong>Example</strong></td></tr><tr><td>1</td><td>showvalue</td><td>To get hardware value from web service.</td><td>http get</td><td><pre><code class="language-plaintext">&lt;endpoint&gt;/showvalue/2/433</code></pre></td></tr><tr><td>2</td><td>updatevalue</td><td>Update the hardware value passed as a parameter</td><td>http get</td><td><pre><code class="language-plaintext">&lt;endpoint&gt;/updatevalue/2/433/2</code></pre></td></tr><tr><td>3</td><td>showjson</td><td>To get hardware JSON from web service.</td><td>http get</td><td><pre><code class="language-plaintext">&lt;endpoint&gt;/showjson/2/433</code></pre></td></tr><tr><td>4</td><td>updatejson</td><td>Update the hardware JSON passed as parameter</td><td>http post</td><td><pre><code class="language-plaintext">&lt;endpoint&gt;/updatejson/2/433 &lt;Data&gt;</code></pre></td></tr><tr><td>5</td><td>showxml</td><td>To get hardware XML file from web service.</td><td>http get</td><td><pre><code class="language-plaintext">&lt;endpoint&gt;/showxml/2/433</code></pre></td></tr><tr><td>6</td><td>updatexml</td><td>Update the hardware XML passed as parameter</td><td>http post</td><td><pre><code class="language-plaintext">&lt;endpoint&gt;/updatexml/2/433 &lt;Data&gt;</code></pre></td></tr></tbody></table>

---

### 2\. Python Library

Users are expected to take these steps,

1.  Install Python Library  
    `pip install openioe`
2.  Write the client code using the following methods

#### Method List:

<table><tbody><tr><td><strong>No</strong></td><td><strong>Method</strong></td><td><strong>Description</strong></td><td><strong>Example</strong></td></tr><tr><td>1</td><td>ReadAPI</td><td>To read the sensor data from multiple nodes</td><td><pre><code class="language-python">from openioe.openioe_apis import *
oi=openioe_apis()
oi.UserIDPinAPIKeys=[[2, 433], [3, 986]]
SensorData,ResposeCode=oi.ReadAPI()
print(SensorData)
print(ResposeCode)</code></pre></td></tr><tr><td>2</td><td>WriteAPI</td><td>To modify the control signal at multiple nodes</td><td><pre><code class="language-python">from openioe.openioe_apis import *
oi=openioe_apis()
oi.UserIDPinAPIKeys=[[2, 433], [3, 986]]

oi.Data=[1,2]
Confirmation,ResposeCode=oi.ReadAPI()
print(Confirmation)
print(ResposeCode)</code></pre></td></tr><tr><td>3</td><td>Developer</td><td>To display the developer information</td><td><pre><code class="language-python">from openioe.openioe_apis import *
oi=openioe_apis()
oi.Developer()</code></pre></td></tr></tbody></table>

---

### Developers
<p>
 <img src="https://venkataswamy.in/images/img1.jpg" alt="Dr. Venkataswamy R" width="100"> 
</p>

<div><div dir="ltr"><div style="font-size:small"><i><font face="times new roman, serif">Thanks and Regards</font><font face="arial">,</font></i></div><div style="font-family:arial"><b><font size="2" color="#0000ff"><span></span>Venkataswamy R</font><font size="2"><span></span></font></b></div><div style="font-size:small"><span style="color:rgb(0,0,0)"><font face="trebuchet ms, sans-serif"><b>Assistant Professor,</b></font></span></div><div style="font-size:small"><span style="color:rgb(0,0,0)"><font face="trebuchet ms, sans-serif"><b>Department of Electrical and Electronics Engineering,</b></font></span></div><div style="font-size:small"><span style="color:rgb(0,0,0)"><font face="trebuchet ms, sans-serif"><b>School of Engineering and Technology,<br></b></font></span></div><div style="font-size:small"><span style="color:rgb(0,0,0)"><font face="trebuchet ms, sans-serif"><b>Christ (Deemed to be University),</b></font></span></div><div style="font-size:small"><span style="color:rgb(56,118,29)"><font face="trebuchet ms, sans-serif"><b><span style="color:rgb(0,0,0)">Bengaluru-560074, India</span><br><br></b></font></span></div><div style="font-family:arial;font-size:small"><b style="color:rgb(7,55,99);font-family:'trebuchet ms',sans-serif"><i><img src="https://ci4.googleusercontent.com/proxy/JGrPNyQPabY_rra4ygFQhpV3cMA7ITqb5WxBKVcm5J7nUXsWZgk4oUuqR-1Dso97mGx5TF4OvAWyEvAm6fA0h9EhgVZcO6VnO77JetkXhoxX6-7YrakgsA=s0-d-e1-ft#https://openclipart.org/image/2400px/svg_to_png/262221/phone25.png" alt="Image result for phone icon" style="margin-top:0px" width="17" height="14"> 080-4012-9961 (O)</i></b><font face="trebuchet ms, sans-serif" color="#073763"><b><i>&nbsp;&nbsp; </i></b></font><b style="color:rgb(7,55,99);font-family:'trebuchet ms',sans-serif"><i><img src="https://ci4.googleusercontent.com/proxy/xDyzoCUBYbAyKgjwt27Jl4lkN_6MrkWuk-4BQ2IgMCZEuCMwJLtZjRYqLSrgS6SGWQcpQOVuNmBzqrKJpes9riut82x8hJ1GJVKL=s0-d-e1-ft#http://simpleicon.com/wp-content/uploads/mobile-1.png" style="margin-top:0px" alt="Image result for mobile icon" width="21" height="21">+91-7829222446</i></b><i><b>&nbsp; </b></i><img src="https://lh4.googleusercontent.com/-FqpLVHU8eMw/AAAAAAAAAAI/AAAAAAAAABM/ivbX55TtoV4/photo.jpg" alt="Related image" style="margin-top:0px" width="21" height="21"><span><b style="color:rgb(7,55,99);font-family:'trebuchet ms',sans-serif"><i> <a href="http://venkataswamy.in" target="_blank">venkatswamy.in</a><br><br><br></i></b></span></div></div></div>